Cheshire3 Object Model - Parser
===============================

.. _objects-parser-api:

API
---

.. autoclass:: cheshire3.baseObjects.Parser
   :members:


.. _objects-parser-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.parser.MinidomParser

.. autoclass:: cheshire3.parser.SaxParser

.. autoclass:: cheshire3.parser.StoredSaxParser

.. autoclass:: cheshire3.parser.LxmlParser

.. autoclass:: cheshire3.parser.LxmlHtmlParser

.. autoclass:: cheshire3.parser.PassThroughParser

.. autoclass:: cheshire3.parser.MarcParser
